@@ -4,8 +4,10 @@ from django.contrib import admin, messages
 from django.db.models import QuerySet
 from django.http import HttpRequest
 
+import requests
+
 from metroid.config import settings
-from metroid.models import FailedMessage
+from metroid.models import FailedMessage, FailedPublishMessage
 
 logger = logging.getLogger('metroid')
 
@@ -76,3 +78,51 @@ class FailedMessageAdmin(admin.ModelAdmin):
                     level=messages.WARNING,
                 )
         return
+
+
+@admin.register(FailedPublishMessage)
+class FailedPublishMessageAdmin(admin.ModelAdmin):
+    readonly_fields = (
+        'correlation_id',
+        'data',
+        'data_version',
+        'event_time',
+        'event_type',
+        'topic_name',
+        'subject',
+    )
+    list_display = ['id', 'correlation_id', 'topic_name', 'subject', 'event_time']
+
+    actions = ['retry_publish']
+
+    def retry_publish(self, request: HttpRequest, queryset: QuerySet) -> None:
+        """
+        Retry messages that failed to publish.
+        """
+        for message in queryset:
+            try:
+                metro_response = requests.post(
+                    url=f'https://api.intility.no/metro/{message.topic_name}',
+                    headers={
+                        'content-type': 'application/json',
+                        'x-metro-key': settings.get_x_metro_key(topic_name=message.topic_name),
+                    },
+                    data=message.data,
+                )
+                metro_response.raise_for_status()
+                logger.info('Deleting %s from database', message.id)
+                message.delete()
+                logger.info('Posted to Metro')
+                self.message_user(
+                    request=request,
+                    message='Message has been republished',
+                    level=messages.SUCCESS,
+                )
+            except Exception as error:
+                logger.exception('Unable to republish Metro message. Error: %s', error)
+                self.message_user(
+                    request=request,
+                    message=f'Unable to republish Metro message. Error: {error}',
+                    level=messages.ERROR,
+                )
+        return
